#!/bin/sh

# compressSpecifiedFolder.sh
# SupportTool
#
# Created by Andy Tzeng on 2009/5/21.
# Copyright 2009 Trend Micro Incorporated. All rights reserved.

usage()
{
    echo "Usage: $0 <compressed scheme> <dst_filename> <specifid_folder>" >&2
    exit 1;
}

changePermission()
{
    if [ ! -z "$SUDO_UID" ]; then
        eval chown $SUDO_UID "$filename"
    fi
}

compressed_zip()
{
    eval zip -r9 "$filename" . >/dev/null
    changePermission;
}

compressed_tar()
{
    eval tar -cvf "$filename" . >/dev/null
    changePermission;
}

compressed_tgz()
{
    eval tar -zcf "$filename" . >/dev/null
    changePermission;
}

compressed_tbz()
{
    eval tar -jcf "$filename" . >/dev/null
    changePermission;
}

if [ "$#" -lt 3 ]; then
    usage;
fi
scheme="$1"
shift 1;
filename="$1"
shift 1;
target="$1";
log_folder=`dirname $filename`;

if [ ! -d "$target" -o ! -r "$target" ]; then
    echo "Access denied" >&2
    exit 2;
fi

if [ ! -d "$log_folder" ]; then
    mkdir -p "$log_folder";
fi
pushd "$target" > /dev/null
touch .placeholder

case "$scheme" in
    zip)
        compressed_zip;
        ;;

    tar)
        compressed_tar;
        ;;

    tgz|tar.gz)
        compressed_tgz;
        ;;

    tbz|tar.bz2)
        compressed_tbz;
        ;;

    *)
        echo "$scheme is not supported" >&2
        ;;
esac
