#!/bin/sh

# serviceStatus.sh
# SupportTool
#
# Created by Andy Tzeng on 2009/5/24.
# Copyright 2009 Trend Micro Incorporated. All rights reserved.

BDL_ID_ITIS_UIMGMT="com.trendmicro.iTIS.UIMgmt"
BDL_ID_GUI_FWK="com.trendmicro.common.GUIUtilFWK"

TM_LIBRARY_PATH="/Library/Application Support/TrendMicro"
TM_SYSTEM_LIBRARY_PATH="/System/Library/TrendMicro"
FRAMEWORKS_PATH="/Library/Frameworks"

DEFAULT_GUI_FWK_PATH="/Library/Frameworks/TMGUIUtil.framework"
TMCC_CORE_CONFIG="/Library/Application Support/TrendMicro/common/conf/tmcccore.conf.plist"

cmd=""

tm_log()
{
    logger -t "Trend Smart Surfing" $1
}

usage()
{
    echo "Usage: $0 [all|install|run]" >&2
    exit 1;
}

check_kext ()
{
	av_kextname="$1"
	msg=`/usr/sbin/kextstat -l | grep -i "${av_kextname}" | grep -v grep`
	if [ -n "$msg" ]; then
        tm_log "Finding kernel extension of trendmicro"
		return 1
	fi
	return 0
}

findGUIFWK()
{
	chk_ret=0;
    GUI_FWK=`mdfind -onlyin "$FRAMEWORKS_PATH" "kMDItemCFBundleIdentifier = '$BDL_ID_GUI_FWK'"`

    # If cannot find the GUIFwk's path, try to use default path
    if [ -z "$GUI_FWK" -o ! -d "$GUI_FWK" ]; then
        GUI_FWK="$DEFAULT_GUI_FWK_PATH";
    fi

    # check GUI fwk whether installed
	if [ -d "$GUI_FWK" ]; then
        tm_log "Finding TMGUI.framework of trendmicro"
        chk_ret=1
    fi
	return $chk_ret
}

findConf()
{
    if [ -f "$TMCC_CORE_CONFIG" ]; then
        return 1
    else
        return 0
    fi
}

checkInstalled()
{
    PREFIX="Installed"
    findGUIFWK;
    if [ $? -eq 1 ]; then
        echo "$PREFIX = 1";
        return;
    fi

    findConf;
    if [ $? -eq 1 ]; then
        echo "$PREFIX = 1";
        return;
    fi

    if [ -d "$TM_LIBRARY_PATH" ] || [ -d "$TM_SYSTEM_LIBRARY_PATH" ]; then
        echo "$PREFIX = 1";
        return;
    fi
    echo "$PREFIX = 0";
}

checkRunning()
{
    PREFIX="Running"
#    check_kext "trendmicro";
#    if [ $? -eq 1 ]; then
#        echo "$PREFIX = 1";
#        return;
#    fi

    ICORE=$(ps A -o command | grep '^\(\/Applications\/.*\/MacOS/\)\?\(iCoreService\)')
    if [ ! -z "$ICORE" ]; then
        tm_log "Finding iCoreService process"
        echo "$PREFIX = 1";
        return;
    fi
    echo "$PREFIX = 0";
}

if [ -z "$1" ]; then
    cmd="all"
fi

RET=0
if [ -z "$1" ]; then
    OPT="all"
else
    OPT="$1"
fi

case "$OPT" in
    install)
        checkInstalled;
        ;;

    run)
        checkRunning;
        ;;

    all)
        checkInstalled;
        checkRunning;
        ;;

    *)
        usage;
        RET=1
        ;;
esac
exit $RET;
